@@ -125,6 +125,16 @@ gtk_dialog_get_vbox(GtkDialog *dialog)
 /****************************************************************
  * This section contains annotations which should go upstream as
  * soon as Gtk+ depends on gobject-introspection
+ *
+ * Annotation/API review status:
+ *
+ * Return value transfer
+ * gtk_container_*: 2.12: Johan Dahlin
+ * gtk_entry_*: 2.12: Johan Dahlin
+ * gtk_widget_get_*: 2.12: Johan Dahlin
+ * gtk_window_get_*: 2.12: Johan Dahlin
+ * GSList/GList*: 2.14: Johan Dahlin
+ *
  */
 
 /**
@@ -184,15 +194,35 @@ gtk_dialog_get_vbox(GtkDialog *dialog)
  */
 
 /**
- * gtk_action_group_add_action_with_accel: 
+ * gtk_accel_group_from_object: 
+ *
+ * Return value: (element-type GtkAccelGroup) (transfer none):
+ */
+
+/**
+ * gtk_action_group_add_action_with_accel:
+ *
  * @accelerator: (allow-none): 
  */
 
 /**
  * gtk_action_group_get_action:
+ *
  * Return value: (transfer none):
  */
 
+/**
+ * gtk_action_group_get_proxies:
+ *
+ * Return value: (element-type GtkWidget) (transfer none):
+ */
+
+/**
+ * gtk_action_group_list_actions:
+ *
+ * Return value: (element-type GtkAction) (transfer container):
+ */
+
 /**
  * gtk_action_set_accel_group: 
  * @accel_group: (allow-none): 
@@ -227,6 +257,18 @@ gtk_dialog_get_vbox(GtkDialog *dialog)
  * Deprecated: 2.14: Use gtk_box_pack_start()
  */
 
+/**
+ * gtk_builder_get_objects:
+ *
+ * Return value: (element-type GObject) (transfer container):
+ */
+
+/**
+ * gtk_cell_layout_get_cell_renderers:
+ *
+ * Return value: (element-type GtkCellRenderer) (transfer container):
+ */
+
 /**
  * gtk_cell_view_set_displayed_row: 
  * @path: (allow-none): 
@@ -242,9 +284,16 @@ gtk_dialog_get_vbox(GtkDialog *dialog)
  * @mask: (allow-none): 
  */
 
+/* FIXME: This should be done in gobject-introspection itself,
+          instead of here. It probably applies to all alternative
+          constructors.
+          Verify that GJS works before removing this.
+          Johan 2008-12-09
+ */
 /**
- * gtk_combo_box_set_model: 
- * @model: (allow-none): 
+ * gtk_combo_box_new_text:
+ *
+ * Return value: (transfer none):
  */
 
 /**
@@ -253,11 +302,28 @@ gtk_dialog_get_vbox(GtkDialog *dialog)
  * Return value: (transfer none):
  */
 
+/**
+ * gtk_combo_box_set_model: 
+ * @model: (allow-none): 
+ */
+
 /**
  * gtk_container_get_children: 
  * @container: 
  *
- * Return value: (element-type Widget) (transfer container): List of #GtkWidget
+ * Return value: (element-type GtkWidget) (transfer container): List of #GtkWidget
+ */
+
+/**
+ * gtk_container_get_focus_hadjustment: 
+ *
+ * Return value: (transfer none): 
+ */
+
+/**
+ * gtk_container_get_focus_vadjustment: 
+ *
+ * Return value: (transfer none): 
  */
 
 /**
@@ -330,6 +396,24 @@ gtk_dialog_get_vbox(GtkDialog *dialog)
  * @model: (allow-none): 
  */
 
+/**
+ * gtk_entry_get_cursor_hadjustment: 
+ *
+ * Return value: (transfer none)
+ */
+
+/**
+ * gtk_entry_get_inner_border: 
+ *
+ * Return value: (transfer none)
+ */
+
+/**
+ * gtk_entry_get_layout: 
+ *
+ * Return value: (transfer none)
+ */
+
 /**
  * gtk_entry_set_completion: 
  * @completion: (allow-none): 
@@ -355,6 +439,42 @@ gtk_dialog_get_vbox(GtkDialog *dialog)
  * @label_widget: (allow-none): 
  */
 
+/**
+ * gtk_file_chooser_get_filenames: 
+ *
+ * Return value: (element-type utf8) (transfer full):
+ */
+
+/**
+ * gtk_file_chooser_get_uris: 
+ *
+ * Return value: (element-type utf8) (transfer full): 
+ */
+
+/**
+ * gtk_file_chooser_get_files: 
+ *
+ * Return value: (element-type utf8) (transfer full): 
+ */
+
+/**
+ * gtk_file_chooser_list_filters: 
+ *
+ * Return value: (element-type utf8) (transfer container): 
+ */
+
+/**
+ * gtk_file_chooser_list_shortcut_folders: 
+ *
+ * Return value: (element-type utf8) (transfer full): 
+ */
+
+/**
+ * gtk_file_chooser_list_shortcut_folder_uris: 
+ *
+ * Return value: (element-type utf8) (transfer full): 
+ */
+
 /**
  * gtk_frame_set_label: 
  * @label: (allow-none): 
@@ -374,13 +494,31 @@ gtk_dialog_get_vbox(GtkDialog *dialog)
 /**
  * gtk_icon_theme_get_default:
  *
- * Return: (transfer none):
+ * Return value: (transfer none):
  */
 
 /**
  * gtk_icon_theme_get_for_screen:
  *
- * Return: (transfer none):
+ * Return value: (transfer none):
+ */
+
+/**
+ * gtk_icon_theme_list_contexts:
+ *
+ * Return value: (element-type utf8) (transfer full):
+ */
+
+/**
+ * gtk_icon_theme_list_icons:
+ *
+ * Return value: (element-type utf8) (transfer none):
+ */
+
+/**
+ * gtk_icon_view_get_selected_items:
+ *
+ * Return value: (element-type GtkTreePath) (transfer full): 
  */
 
 /**
@@ -442,19 +580,19 @@ gtk_dialog_get_vbox(GtkDialog *dialog)
  */
 
 /**
- * gtk_init
+ * gtk_init:
  * @argc: (inout): 
  * @argv: (array length=argc) (inout): 
  */
 
 /**
- * gtk_init_check
+ * gtk_init_check:
  * @argc: (inout): 
  * @argv: (array length=argc) (inout): 
  */
 
 /**
- * gtk_init_with_args
+ * gtk_init_with_args:
  * @argc: (inout): 
  * @argv: (array length=argc) (inout): 
  */
@@ -507,6 +645,12 @@ gtk_dialog_get_vbox(GtkDialog *dialog)
  * @position: (allow-none): 
  */
 
+/**
+ * gtk_menu_get_for_attach_widget: 
+ *
+ * Return value: (element-type GtkWidget) (transfer none):
+ */
+
 /**
  * gtk_menu_item_set_accel_path: 
  * @accel_path: (allow-none): 
@@ -745,7 +889,13 @@ gtk_dialog_get_vbox(GtkDialog *dialog)
  */
 
 /**
- * gtk_parse_args
+ * gtk_paper_size_get_papers_sizes: 
+ *
+ * Return value: (element-type GtkPaperSize) (transfer full): 
+ */
+
+/**
+ * gtk_parse_args:
  * @argc: (inout): 
  * @argv: (array) (inout): 
  */
@@ -760,6 +910,18 @@ gtk_dialog_get_vbox(GtkDialog *dialog)
  * @mask: (allow-none): 
  */
 
+/**
+ * gtk_printer_backend_get_printer_list: 
+ *
+ * Return value: (element-type GtkPrinter) (transfer container): 
+ */
+
+/**
+ * gtk_printer_backend_load_modules: 
+ *
+ * Return value: (element-type GtkPrintBackend) (transfer container): 
+ */
+
 /**
  * gtk_print_operation_run: 
  * @parent: (allow-none): 
@@ -791,15 +953,39 @@ gtk_dialog_get_vbox(GtkDialog *dialog)
  * @value: (allow-none): 
  */
 
+/**
+ * gtk_printer_list_papers: 
+ *
+ * Return value: (element-type GtkPageSetup) (transfer full): 
+ */
+
+/**
+ * gtk_printer_option_set_get_groups: 
+ *
+ * Return value: (element-type utf8) (transfer full): 
+ */
+
 /**
  * gtk_progress_bar_new_with_adjustment: 
  * @adjustment: (allow-none): 
  */
 
+/**
+ * gtk_radio_action_get_group:
+ *
+ * Return value: (element-type GtkAction) (transfer none):
+ */
+
 /**
  * gtk_radio_button_get_group:
  *
- * Return value: (element-type Widget) (transfer none):
+ * Return value: (element-type GtkWidget) (transfer none):
+ */
+
+/**
+ * gtk_radio_menu_item_get_group:
+ *
+ * Return value: (element-type GtkWidget) (transfer none):
  */
 
 /**
@@ -808,6 +994,18 @@ gtk_dialog_get_vbox(GtkDialog *dialog)
  * @class_path: (allow-none): 
  */
 
+/**
+ * gtk_recent_chooser_get_items:
+ *
+ * Return value: (element-type GtkRecentInfo) (transfer full): List of #GtkRecentInfo
+ */
+
+/**
+ * gtk_recent_chooser_list_filters:
+ *
+ * Return value: (element-type GtkRecentFilter) (transfer container): List of #GtkRecentFilter
+ */
+
 /**
  * gtk_recent_manager_get_items:
  * @manager: 
@@ -817,7 +1015,7 @@ gtk_dialog_get_vbox(GtkDialog *dialog)
 
 /**
  * gtk_recent_info_get_application_info:
- * @app_exec: (out):
+ * @app_exec: (transfer none) (out):
  * @count: (out):
  * @time_: (out):
  *
@@ -844,6 +1042,18 @@ gtk_dialog_get_vbox(GtkDialog *dialog)
  * @widget: (allow-none): 
  */
 
+/**
+ * gtk_settings_get_default:
+ *
+ * Return value: (transfer none):
+ */
+
+/**
+ * gtk_size_group_get_widgets: 
+ *
+ * Return value: (element-type GtkWidget) (transfer none): 
+ */
+
 /**
  * gtk_spin_button_configure: 
  * @adjustment: (allow-none): 
@@ -859,6 +1069,12 @@ gtk_dialog_get_vbox(GtkDialog *dialog)
  * @tooltip_text: (allow-none): 
  */
 
+/**
+ * gtk_stock_list_ids: 
+ *
+ * Return value: (element-type utf8) (transfer full):
+ */
+
 /**
  * gtk_style_apply_default_background: 
  * @area: (allow-none): 
@@ -890,6 +1106,12 @@ gtk_dialog_get_vbox(GtkDialog *dialog)
  * @tagset_name: (allow-none): 
  */
 
+/**
+ * gtk_text_child_anchor_get_widgets: 
+ *
+ * Return value: (element-type GtkWidget) (transfer container): 
+ */
+
 /**
  * gtk_text_iter_backward_search: 
  * @limit: (allow-none): 
@@ -920,11 +1142,35 @@ gtk_dialog_get_vbox(GtkDialog *dialog)
  * @tag: (allow-none): 
  */
 
+/**
+ * gtk_text_iter_get_marks: 
+ *
+ * Return value: (element-type GtkTextMark) (transfer container):
+ */
+
+/**
+ * gtk_text_iter_get_toggled_tags:
+ *
+ * Return value: (element-type GtkTextTag) (transfer container):
+ */
+
+/**
+ * gtk_text_iter_get_tags:
+ *
+ * Return value: (element-type GtkTextTag) (transfer container):
+ */
+
 /**
  * gtk_text_iter_toggles_tag: 
  * @tag: (allow-none): 
  */
 
+/**
+ * gtk_text_layout_get_lines: 
+ *
+ * Return value: (element-type GtkTextLine) (transfer container):
+ */
+
 /**
  * gtk_text_layout_set_buffer: 
  * @buffer: (allow-none): 
@@ -1046,6 +1292,12 @@ gtk_dialog_get_vbox(GtkDialog *dialog)
  * @child_iter: (allow-none): 
  */
 
+/**
+ * gtk_tree_selection_get_selected_rows: 
+ *
+ * Return value: (element-type GtkTreePath) (transfer full): 
+ */
+
 /**
  * gtk_tree_store_move_after: 
  * @position: (allow-none): 
@@ -1066,6 +1318,12 @@ gtk_dialog_get_vbox(GtkDialog *dialog)
  * @column: (allow-none): 
  */
 
+/**
+ * gtk_tree_view_get_columns: 
+ *
+ * Return value: (element-type GtkTreeViewColumn) (transfer container): 
+ */
+
 /**
  * gtk_tree_view_move_column_after: 
  * @base_column: (allow-none): 
@@ -1102,6 +1360,30 @@ gtk_dialog_get_vbox(GtkDialog *dialog)
  * @action: (allow-none): 
  */
 
+/**
+ * gtk_ui_manager_get_accel_group: 
+ *
+ * Return value: (transfer none): 
+ */
+
+/**
+ * gtk_ui_manager_get_action_groups: 
+ *
+ * Return value: (element-type GtkActionGroup) (transfer none): 
+ */
+
+/**
+ * gtk_ui_manager_get_toplevels: 
+ *
+ * Return value: (element-type GtkWidget) (transfer container): 
+ */
+
+/**
+ * gtk_ui_manager_get_widget: 
+ *
+ * Return value: (transfer none): 
+ */
+
 /**
  * gtk_viewport_set_hadjustment: 
  * @adjustment: (allow-none): 
@@ -1119,31 +1401,146 @@ gtk_dialog_get_vbox(GtkDialog *dialog)
  * @path_reversed: (out): 
  */
 
+/**
+ * gtk_widget_get_accessible:
+ *
+ * Return value: (transfer none):
+ */
+
+/**
+ * gtk_widget_get_ancestor:
+ *
+ * Return value: (transfer none):
+ */
+
+/**
+ * gtk_widget_get_clipboard:
+ *
+ * Return value: (transfer none):
+ */
+
+/**
+ * gtk_widget_get_colormap:
+ *
+ * Return value: (transfer none):
+ */
+
+/**
+ * gtk_widget_get_default_colormap:
+ *
+ * Return value: (transfer none):
+ */
+
+/**
+ * gtk_widget_get_default_style:
+ *
+ * Return value: (transfer none):
+ */
+
+/**
+ * gtk_widget_get_default_visual:
+ *
+ * Return value: (transfer none):
+ */
+
+/**
+ * gtk_widget_get_display:
+ *
+ * Return value: (transfer none):
+ */
+
+/**
+ * gtk_widget_get_modifier_style:
+ *
+ * Return value: (transfer none):
+ */
+
+/**
+ * gtk_widget_get_pango_context:
+ *
+ * Return value: (transfer none):
+ */
+
+/**
+ * gtk_widget_get_parent:
+ *
+ * Return value: (transfer none):
+ */
+
+/**
+ * gtk_widget_get_parent_window:
+ *
+ * Return value: (transfer none):
+ */
+
 /**
  * gtk_widget_get_pointer: 
  * @x: (out): 
  * @y: (out): 
  */
 
+/**
+ * gtk_widget_get_root_window:
+ *
+ * Return value: (transfer none):
+ */
+
+/**
+ * gtk_widget_get_screen: 
+ *
+ * Return value: (transfer none):
+ */
+
+/**
+ * gtk_widget_get_settings: 
+ *
+ * Return value: (transfer none):
+ */
+
 /**
  * gtk_widget_get_size_request: 
  * @width: (out): 
  * @height: (out): 
  */
 
+/**
+ * gtk_widget_get_style: 
+ *
+ * Return value: (transfer none):
+ */
+
+/**
+ * gtk_widget_get_tooltip_window:
+ *
+ * Return value: (transfer none):
+ */
+
+/**
+ * gtk_widget_get_toplevel:
+ *
+ * Return value: (transfer none):
+ */
+
+/**
+ * gtk_widget_get_visual:
+ *
+ * Return value: (transfer none):
+ */
+
 /**
  * gtk_widget_input_shape_combine_mask: 
  * @shape_mask: (allow-none): 
  */
 
 /**
- * gtk_widget_modify_base: 
- * @color: (allow-none): 
+ * gtk_widget_list_mnemonic_lables: 
+ *
+ * Return value: (element-type GtkWidget) (transfer container):
  */
 
 /**
- * gtk_widget_get_toplevel:
- * Return value: (transfer none):
+ * gtk_widget_modify_base: 
+ * @color: (allow-none): 
  */
 
 /**
@@ -1202,8 +1599,45 @@ gtk_dialog_get_vbox(GtkDialog *dialog)
  */
 
 /**
- * gtk_window_set_default: 
- * @default_widget: (allow-none): 
+ * gtk_window_get_default_icon_list: 
+ * 
+ * Return value: (element-type GdkPixbuf) (transfer container):
+ */
+
+/**
+ * gtk_window_get_focus: 
+ * 
+ * Return value: (transfer none):
+ */
+
+/**
+ * gtk_window_get_gravity: 
+ * 
+ * Return value: (transfer none):
+ */
+
+/**
+ * gtk_window_get_group: 
+ * 
+ * Return value: (transfer none):
+ */
+
+/**
+ * gtk_window_get_icon: 
+ * 
+ * Return value: (transfer none):
+ */
+
+/**
+ * gtk_window_get_icon_list: 
+ * 
+ * Return value: (element-type GdkPixbuf) (transfer container):
+ */
+
+/**
+ * gtk_window_get_screen: 
+ * 
+ * Return value: (transfer none):
  */
 
 /**
@@ -1212,6 +1646,29 @@ gtk_dialog_get_vbox(GtkDialog *dialog)
  * @height: (out): 
  */
 
+/**
+ * gtk_window_get_transient_for: 
+ * 
+ * Return value: (transfer none):
+ */
+
+/**
+ * gtk_window_group_list_windows: 
+ * 
+ * Return value: (element-type GtkWidget) (transfer container):
+ */
+
+/**
+ * gtk_window_list_toplevels: 
+ * 
+ * Return value: (element-type GtkWidget) (transfer container):
+ */
+
+/**
+ * gtk_window_set_default: 
+ * @default_widget: (allow-none): 
+ */
+
 /**
  * gtk_window_set_focus: 
  * @focus: (allow-none): 
